# Python Own Certificate Authority (ownca)

ownca make easy to handle a Certificate Authority (CA) and manage certificates
for hosts or clients.


## Installation

pip install ownca

(...comming soon)
